aboutsummaryrefslogtreecommitdiffstats
path: root/android/opengles.h
diff options
context:
space:
mode:
Diffstat (limited to 'android/opengles.h')
-rw-r--r--android/opengles.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/android/opengles.h b/android/opengles.h
index 2202e92..7bb6a3a 100644
--- a/android/opengles.h
+++ b/android/opengles.h
@@ -16,6 +16,10 @@
#define ANDROID_OPENGLES_BASE_PORT 22468
+/* See the description in render_api.h. */
+typedef void (*OnPostFn)(void* context, int width, int height, int ydir,
+ int format, int type, unsigned char* pixels);
+
/* Call this function to initialize the hardware opengles emulation.
* This function will abort if we can't find the corresponding host
* libraries through dlopen() or equivalent.
@@ -23,9 +27,11 @@
int android_initOpenglesEmulation(void);
/* Tries to start the renderer process. Returns 0 on success, -1 on error.
* At the moment, this must be done before the VM starts.
*/
-int android_startOpenglesRenderer(int width, int height);
+int android_startOpenglesRenderer(int width, int height,
+ OnPostFn onPost, void* onPostContext);
int android_showOpenglesWindow(void* window, int x, int y, int width, int height, float rotation);
@@ -23,9 +27,11 @@
int android_initOpenglesEmulation(void);
/* Tries to start the renderer process. Returns 0 on success, -1 on error.
- * At the moment, this must be done before the VM starts.
+ * At the moment, this must be done before the VM starts. The onPost callback
+ * may be NULL.
*/